# Minimum GNOME Shell version supported
%global min_gs_version %%(cut -d "." -f 1-3 <<<%{version})

# filter out private typelib req from mutter,
# mutter is already pulled with gnome-shell
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}^typelib\\(Meta

Name:		gnome-shell-extensions
Version:	48.3
Release:	%mkrel 1
Summary:	Modify and extend GNOME Shell functionality and behavior
Group:		Graphical desktop/GNOME
License:        GPLv2+
URL:		https://wiki.gnome.org/GnomeShell/Extensions
Source0:	https://download.gnome.org/sources/%{name}/%{url_ver}/%{name}-%{version}.tar.xz
Patch0:		gnome-shell-extensions-gnome-classic.patch
BuildRequires:	meson
BuildRequires:	desktop-file-utils
BuildRequires:	gettext
BuildRequires:	pkgconfig(glib-2.0)
# ovitters: ensure gnome-shell is available and built before this package
BuildRequires:	gnome-shell >= %{min_gs_version}
# ovitters: pkgconfig(gobject-introspection-1.0) includes script to determine typelib() auto buildrequires
BuildRequires:	pkgconfig(gobject-introspection-1.0)
Recommends:	%{name}-apps-menu
Recommends:	%{name}-auto-move-windows
Recommends:	%{name}-drive-menu
Recommends:	%{name}-gajim
Recommends:	%{name}-launch-new-instance
Recommends:	%{name}-native-window-placement
Recommends:	%{name}-places-menu
Recommends:	%{name}-systemMonitor
Recommends:	%{name}-user-theme
Recommends:	%{name}-windowsNavigator
Recommends:	%{name}-workspace-indicator
Requires:	gnome-shell >= %{min_gs_version}
Requires:	gnome-session
# ensure we use the upstream session file:
Conflicts:	desktop-common-data < 1:3.10-2
BuildArch:	noarch

# ovitters: removed as per 3.9.5
Conflicts:	%{name}-alternative-status-menu <= 3.9.4
# ovitters: removed as per 3.9.90
Conflicts:	%{name}-xrandr-indicator <= 3.9.5

%description
GNOME Shell Extensions is a collection of extensions providing additional
and optional functionality to GNOME Shell.

Enabled extensions:

  * apps-menu
  * auto-move-windows
  * drive-menu
  * launch-new-instance
  * light-style
  * native-window-placement
  * places-menu
  * screenshot-window-sizer
  * status-icons
  * system-monitor
  * user-theme
  * window-list
  * windowsNavigator
  * workspace-indicator

%package common
Summary:	Files common to GNOME Shell Extensions
Group:		Graphical desktop/GNOME
Requires:       gnome-shell >= %{min_gs_version}
# Dock extension no longer provides by GNOME Shell extensions >= 3.7.1
Obsoletes:      %{name}-dock < 3.7.1
# systemMonitor gone as of 3.15.91
Obsoletes:	%{name}-systemMonitor < 3.15.91
# classic overrides moved to gnome-classic-session as of 3.29.90
Obsoletes:	%{name}-overrides < 3.29.90
# gone in 3.32
Obsoletes:	gnome-shell-extensions-alternate-tab < 3.31.92
# gone in 40.0
Obsoletes:      gnome-shell-extensions-horizontal-workspaces < 40.0-1

%description common
GNOME Shell Extensions is a collection of extensions providing additional
and optional functionality to GNOME Shell. Common files and directories
needed by extensions are provided here.

%package -n gnome-classic-session
Summary:        GNOME "classic" mode session
Group:          Graphical desktop/GNOME
Requires:       %{name}-apps-menu = %{version}-%{release}
Requires:       %{name}-launch-new-instance = %{version}-%{release}
Requires:       %{name}-places-menu = %{version}-%{release}
Requires:       %{name}-window-list = %{version}-%{release}

%description -n gnome-classic-session
This package contains the required components for the GNOME Shell "classic"
mode, which aims to provide a GNOME 2-like user interface.

%package apps-menu
Summary:	Gnome 2.x style menu on the panel
Group:		Graphical desktop/GNOME
Requires:	%{name}-common = %{version}-%{release}

%description apps-menu
Lets you reach an application using gnome 2.x style menu on the panel.

%package auto-move-windows
Summary:	Assign specific workspaces to applications
Group:		Graphical desktop/GNOME
Requires:	%{name}-common = %{version}-%{release}

%description auto-move-windows
Lets you manage your workspaces more easily, assigning a specific workspace
to each application as soon as it creates a window, in a manner configurable
with a GSettings key.

%package drive-menu
Summary:	Disk device manager in the system status area
Group:		Graphical desktop/GNOME
Requires:	%{name}-common = %{version}-%{release}

%description drive-menu
Adds a menu in the system status area that tracks removable disk devices
attached and offers to browse them and eject/unmount them.

%package launch-new-instance
Summary:        Always launch a new application instance for GNOME Shell
Group:          Graphical desktop/GNOME
Requires:       %{name}-common = %{version}-%{release}

%description  launch-new-instance
This GNOME Shell extension modifies the behavior of clicking in the dash and app
launcher to always launch a new application instance.

%package light-style
Summary:        Use light style in GNOME Shell
License:        GPLv2+
Requires:       %{name}-common = %{version}-%{release}

%description light-style
This GNOME Shell extension changes the default style to light.


%package native-window-placement
Summary:	Arrange windows in overview in a more native way
Group:		Graphical desktop/GNOME
Requires:	%{name}-common = %{version}-%{release}

%description native-window-placement
This extension employs an algorithm (taken from KDE) for laying out the
thumbnails in the overview that more closely reflects the positions and
relative sizes of the actual windows, instead of using a fixed grid.

%package places-menu
Summary:	Places menu indicator in the system status area
Group:		Graphical desktop/GNOME
Requires:	%{name}-common = %{version}-%{release}

%description places-menu
Adds a menu in the system status area that resembles the Places menu from
GNOME 2.x

%package screenshot-window-sizer
Summary:	Screenshot window sizer for GNOME Shell
Group:		Graphical desktop/GNOME
License:	GPLv2+
Requires:	%{name}-common = %{version}-%{release}

%description screenshot-window-sizer
This GNOME Shell extension allows to easily resize windows for GNOME Software
screenshots.

%package status-icons
Summary:	Status icons support for GNOME Shell
Group:		Graphical desktop/GNOME
License:	GPL-2.0-or-later
Requires:	%{name}-common = %{version}-%{release}

%description status-icons
This GNOME Shell extension displays status icons in the top bar.

%package system-monitor
Summary:	System monitor for GNOME Shell
Group:		Graphical desktop/GNOME
License:	GPLv2+
Requires:	%{name}-common = %{version}-%{release}

%description system-monitor
This GNOME Shell extension displays system usage information in the top bar.

%package user-theme
Summary:	Lets the user select a custom theme for the shell
Group:		Graphical desktop/GNOME
Requires:	%{name}-common = %{version}-%{release}

%description user-theme
Lets the user select a custom theme for the Gnome shell. It will allow you to
apply a style from /.themes/[themeName]/gnome-shell/gnome-shell.css

%package window-list
Summary:        Display a window list at the bottom of the screen in GNOME Shell
Group:          Graphical desktop/GNOME
Requires:       %{name}-common = %{version}-%{release}

%description window-list
This GNOME Shell extension displays a window list at the bottom of the screen.

%package windowsNavigator
Summary:	Keyboard selection of windows and work-spaces in overlay mode
Group:		Graphical desktop/GNOME
Requires:	%{name}-common = %{version}-%{release}

%description windowsNavigator
Allow keyboard selection of windows and work-spaces in overlay mode in
GNOME Shell.

Switch to overview mode (press the windows or alt+f1 key) and
press the alt key to show numbers over windows.  Press any number to switch
to the corresponding window.

%package workspace-indicator
Summary:	A menu for changing workspace
Group:		Graphical desktop/GNOME
Requires:	%{name}-common = %{version}-%{release}

%description workspace-indicator
A menu for changing workspace.

%prep
%autosetup -p1

%build
%meson -Dextension_set="all" -Dclassic_mode=true
%meson_build

%install
%meson_install

# Drop useless example extension
#rm -r %%{buildroot}%%{_datadir}/gnome-shell/extensions/example*
#rm %%{buildroot}%%{_datadir}/glib-2.0/schemas/org.gnome.shell.extensions.example.gschema.xml

# helper script
mkdir -p %buildroot%{_bindir}
cat << EOF >%{buildroot}%{_bindir}/startgnome_classic
#!/bin/sh
GNOME_SHELL_SESSION_MODE=classic
export GNOME_SHELL_SESSION_MODE
exec gnome-session
EOF
chmod 755 %{buildroot}%{_bindir}/startgnome_classic

%find_lang %{name}

# make sure to nuke pre-mga6 generated session:
%posttrans -n gnome-classic-session
# (ovitters) In posttrans, $1 is always equal to 1, even in the upgrade case.
# So just run this always:
if [ -e %{_datadir}/xsessions/03GNOMEClassic.desktop ]; then
        rm -rf %{_datadir}/xsessions/03GNOMEClassic.desktop
fi
if [ -e %{_sysconfdir}/X11/dm/Sessions/03GNOMEClassic.desktop ]; then
        rm -rf %{_sysconfdir}/X11/dm/Sessions/03GNOMEClassic.desktop
fi

%files common -f %{name}.lang
%doc README.md
%dir %{_datadir}/gnome-shell/extensions/

%files -n gnome-classic-session
%{_bindir}/startgnome_classic
%{_datadir}/gnome-shell/modes/classic.json
%{_datadir}/glib-2.0/schemas/00_org.gnome.shell.extensions.classic.gschema.override
%{_datadir}/xsessions/*
%{_datadir}/wayland-sessions/gnome-classic.desktop
%{_datadir}/wayland-sessions/gnome-classic-wayland.desktop

%files apps-menu
%{_datadir}/glib-2.0/schemas/org.gnome.shell.extensions.apps-menu.gschema.xml
%{_datadir}/gnome-shell/extensions/apps-menu*

%files auto-move-windows
%{_datadir}/glib-2.0/schemas/org.gnome.shell.extensions.auto-move-windows.gschema.xml
%{_datadir}/gnome-shell/extensions/auto-move-windows*

%files drive-menu
%{_datadir}/gnome-shell/extensions/drive-menu*

%files launch-new-instance
%{_datadir}/gnome-shell/extensions/launch-new-instance*

%files light-style
%{_datadir}/gnome-shell/extensions/light-style*/

%files native-window-placement
%{_datadir}/glib-2.0/schemas/org.gnome.shell.extensions.native-window-placement.gschema.xml
%{_datadir}/gnome-shell/extensions/native-window-placement*

%files places-menu
%{_datadir}/gnome-shell/extensions/places-menu*

%files screenshot-window-sizer
%{_datadir}/glib-2.0/schemas/org.gnome.shell.extensions.screenshot-window-sizer.gschema.xml
%{_datadir}/gnome-shell/extensions/screenshot-window-sizer*/

%files status-icons
%{_datadir}/gnome-shell/extensions/status-icons*/

%files system-monitor
%{_datadir}/glib-2.0/schemas/org.gnome.shell.extensions.system-monitor.gschema.xml
%{_datadir}/gnome-shell/extensions/system-monitor*/

%files user-theme
%{_datadir}/glib-2.0/schemas/org.gnome.shell.extensions.user-theme.gschema.xml
%{_datadir}/gnome-shell/extensions/user-theme*

%files window-list
%{_datadir}/gnome-shell/extensions/window-list*
%{_datadir}/glib-2.0/schemas/org.gnome.shell.extensions.window-list.gschema.xml

%files windowsNavigator
%{_datadir}/gnome-shell/extensions/windowsNavigator*

%files workspace-indicator
%{_datadir}/gnome-shell/extensions/workspace-indicator*
%{_datadir}/glib-2.0/schemas/org.gnome.shell.extensions.workspace-indicator.gschema.xml


%changelog
* Sun Jul 20 2025 daviddavid <daviddavid> 48.3-1.mga10
+ Revision: 2257555
- new version 48.3

* Tue Jul 08 2025 umeabot <umeabot> 48.1-2.mga10
+ Revision: 2251836
- Mageia 10 Mass Rebuild

* Mon Apr 21 2025 daviddavid <daviddavid> 48.1-1.mga10
+ Revision: 2177409
- new version 48.1

* Wed Mar 19 2025 daviddavid <daviddavid> 48.0-1.mga10
+ Revision: 2166735
- new version 48.0

* Sun Dec 01 2024 daviddavid <daviddavid> 47.2-1.mga10
+ Revision: 2120210
- new version 47.2

* Fri Nov 01 2024 daviddavid <daviddavid> 47.1-1.mga10
+ Revision: 2111932
- new version 47.1

* Thu Sep 19 2024 daviddavid <daviddavid> 47.0-1.mga10
+ Revision: 2099070
- new version 47.0

* Sun Jun 02 2024 daviddavid <daviddavid> 46.2-1.mga10
+ Revision: 2069197
- new version 46.2

* Tue Mar 19 2024 daviddavid <daviddavid> 46.0-1.mga10
+ Revision: 2050771
- new version 46.0

* Fri Dec 08 2023 daviddavid <daviddavid> 45.2-2.mga10
+ Revision: 2015582
- rebuild with fixed rpm-mageia-setup-2.73-6.mga10 to generate
  properly typelib()-style Provides/Requires

* Thu Dec 07 2023 daviddavid <daviddavid> 45.2-1.mga10
+ Revision: 2014280
- new version 45.2

* Sat Sep 30 2023 tv <tv> 45.0-1.mga10
+ Revision: 1992415
- Update to 45.0

* Sat Apr 22 2023 tmb <tmb> 44.0-1.mga10
+ Revision: 1953977
- update to 44.0

* Fri Nov 04 2022 ovitters <ovitters> 43.1-1.mga9
+ Revision: 1902527
- new version 43.1

* Wed Sep 21 2022 tv <tv> 43.0-1.mga9
+ Revision: 1891068
- Update to 43.0

* Mon Jul 04 2022 ovitters <ovitters> 42.3-1.mga9
+ Revision: 1867680
- new version 42.3

* Sun May 29 2022 ovitters <ovitters> 42.2-1.mga9
+ Revision: 1860676
- new version 42.2
- new version 42.1

* Wed Mar 16 2022 tv <tv> 42.0-1.mga9
+ Revision: 1794681
- Update to 42.0

* Wed Feb 16 2022 tv <tv> 41.0-2.mga9
+ Revision: 1778216
- Stop obsoleting gnome-applets

* Mon Jan 10 2022 tv <tv> 41.0-1.mga9
+ Revision: 1767684
- Update to 41.0
- Backport GNOME Classic session for Wayland (rhbz#2015741)
- Obsolete gnome-shell-extensions-horizontal-workspaces
+ ovitters <ovitters>
- new version 40.5
- new version 40.4
- new version 40.3

* Thu Jun 10 2021 ovitters <ovitters> 40.2-1.mga9
+ Revision: 1730284
- new version 40.2

* Fri May 14 2021 ovitters <ovitters> 40.1-1.mga9
+ Revision: 1722893
- new version 40.1

* Sat Mar 27 2021 ovitters <ovitters> 40.0-2.mga9
+ Revision: 1711140
- rebuild for move to main

* Fri Mar 26 2021 ovitters <ovitters> 40.0-1.mga9
+ Revision: 1710763
- remove horizontal workspaces extension as it was removed upstream
- new version 40.0
- fix source url

* Thu Dec 03 2020 ovitters <ovitters> 3.38.2-1.mga8
+ Revision: 1651978
- new version 3.38.2

* Mon Oct 05 2020 ovitters <ovitters> 3.38.1-1.mga8
+ Revision: 1632281
- new version 3.38.1

* Tue Sep 15 2020 ovitters <ovitters> 3.38.0-1.mga8
+ Revision: 1626630
- new version 3.38.0

* Sun Sep 06 2020 ovitters <ovitters> 3.37.92-1.mga8
+ Revision: 1622827
- new version 3.37.92

* Mon Aug 24 2020 ovitters <ovitters> 3.37.91-1.mga8
+ Revision: 1618600
- new version 3.37.91

* Tue Aug 11 2020 ovitters <ovitters> 3.37.90-1.mga8
+ Revision: 1613452
- new version 3.37.90
- update gnome-shell-extensions-gnome-classic.patch and helper script
- fix usage of  in posttrans

* Tue Jul 07 2020 ovitters <ovitters> 3.37.3-1.mga8
+ Revision: 1602861
- new version 3.37.3

* Wed Jun 10 2020 ovitters <ovitters> 3.37.2-1.mga8
+ Revision: 1591816
- new version 3.37.2

* Wed Apr 29 2020 ovitters <ovitters> 3.36.2-1.mga8
+ Revision: 1573349
- new version 3.36.2

* Tue Mar 31 2020 ovitters <ovitters> 3.36.1-1.mga8
+ Revision: 1562493
- new version 3.36.1

* Sat Mar 07 2020 ovitters <ovitters> 3.36.0-1.mga8
+ Revision: 1554742
- new version 3.36.0

* Sun Mar 01 2020 ovitters <ovitters> 3.35.92-1.mga8
+ Revision: 1552516
- new version 3.35.92

* Mon Feb 24 2020 tv <tv> 3.35.91-1.mga8
+ Revision: 1549910
- 3.35.91

* Tue Feb 18 2020 umeabot <umeabot> 3.34.2-2.mga8
+ Revision: 1541112
- Mageia 8 Mass Rebuild

* Fri Dec 20 2019 ovitters <ovitters> 3.34.2-1.mga8
+ Revision: 1469036
- new version 3.34.2

* Wed Oct 09 2019 ovitters <ovitters> 3.34.1-1.mga8
+ Revision: 1450678
- new version 3.34.1

* Mon Sep 09 2019 ovitters <ovitters> 3.34.0-1.mga8
+ Revision: 1439050
- new version 3.34.0

* Thu Sep 05 2019 ovitters <ovitters> 3.33.92-1.mga8
+ Revision: 1437434
- new version 3.33.92

* Thu Aug 22 2019 ovitters <ovitters> 3.33.91-1.mga8
+ Revision: 1431093
- new version 3.33.91

* Sat Aug 10 2019 tv <tv> 3.33.90-1.mga8
+ Revision: 1428559
- fix license
+ ovitters <ovitters>
- new version 3.33.90

* Fri Aug 09 2019 tv <tv> 3.33.4-1.mga8
+ Revision: 1428380
- new release

* Wed Apr 17 2019 ovitters <ovitters> 3.32.1-1.mga7
+ Revision: 1392606
- new version 3.32.1

* Wed Apr 17 2019 umeabot <umeabot> 3.32.0-2.mga7
+ Revision: 1392464
- Rebuild with meson 0.50.1

* Tue Mar 12 2019 ovitters <ovitters> 3.32.0-1.mga7
+ Revision: 1374413
- new version 3.32.0

* Sat Mar 09 2019 tmb <tmb> 3.31.92-2.mga7
+ Revision: 1373414
- obsolete gnome-shell-extensions-alternate-tab

* Sat Mar 09 2019 tmb <tmb> 3.31.92-1.mga7
+ Revision: 1373393
- update to 3.31.92

* Mon Oct 08 2018 ovitters <ovitters> 3.30.1-1.mga7
+ Revision: 1318826
- new version 3.30.1

* Thu Sep 20 2018 umeabot <umeabot> 3.30.0-2.mga7
+ Revision: 1278448
- Mageia 7 Mass Rebuild

* Tue Sep 04 2018 ovitters <ovitters> 3.30.0-1.mga7
+ Revision: 1256915
- new version 3.30.0

* Mon Aug 20 2018 ovitters <ovitters> 3.29.91-1.mga7
+ Revision: 1253119
- new version 3.29.91

* Wed Aug 15 2018 blino <blino> 3.29.90-2.mga7
+ Revision: 1251648
- obsolete removed overrides subpackage (new file moved to gnome-classic-session)

* Sat Aug 04 2018 guillomovitch <guillomovitch> 3.29.90-1.mga7
+ Revision: 1247183
- drop obsolete overrides extension
+ ovitters <ovitters>
- new version 3.29.90

* Fri Jul 20 2018 guillomovitch <guillomovitch> 3.29.3-1.mga7
+ Revision: 1244414
- new version 3.29.3

* Wed Apr 25 2018 ovitters <ovitters> 3.28.1-1.mga7
+ Revision: 1222441
- new version 3.28.1

* Mon Mar 12 2018 ovitters <ovitters> 3.28.0-1.mga7
+ Revision: 1208729
- new version 3.28.0

* Mon Mar 05 2018 ovitters <ovitters> 3.27.92-1.mga7
+ Revision: 1206888
- new version 3.27.92
- dropped merged patch fix-classic-session-files.patch

* Fri Feb 23 2018 guillomovitch <guillomovitch> 3.27.91-1.mga7
+ Revision: 1204306
- new version 3.27.91
+ ovitters <ovitters>
- new version 3.27.91
- new version 3.26.2

* Wed Oct 04 2017 ovitters <ovitters> 3.26.1-1.mga7
+ Revision: 1168773
- new version 3.26.1

* Thu Sep 14 2017 tv <tv> 3.26.0-1.mga7
+ Revision: 1153891
- new release

* Thu Jul 20 2017 ovitters <ovitters> 3.24.3-1.mga7
+ Revision: 1125413
- new version 3.24.3

* Thu May 11 2017 ovitters <ovitters> 3.24.2-1.mga6
+ Revision: 1100321
- new version 3.24.2

* Tue Apr 11 2017 ovitters <ovitters> 3.24.1-1.mga6
+ Revision: 1096365
- new version 3.24.1

* Wed Mar 22 2017 ovitters <ovitters> 3.24.0-1.mga6
+ Revision: 1094523
- new version 3.24.0

* Fri Feb 24 2017 wally <wally> 3.22.2-5.mga6
+ Revision: 1087641
- remove xsession leftovers on update also from /etc/X11/dm/Sessions

* Tue Feb 14 2017 wally <wally> 3.22.2-4.mga6
+ Revision: 1086154
- filter out private typelib req from mutter which is pulled already with gnome-shell

* Tue Jan 17 2017 ovitters <ovitters> 3.22.2-3.mga6
+ Revision: 1082206
- explicitly require gnome-session

* Wed Dec 14 2016 ghibo <ghibo> 3.22.2-2.mga6
+ Revision: 1075006
- Use the already provided startgnome_classic init scripts in .desktop
  files: in this way $SESSION env var is detected correctly when desktop
  starts from sddm, otherwise it fails, because it would contain the argument
  of the Exec command line in the .desktop xsession file, which is
  unbearably long and contains multple commands; startgnome_classic just
  contains those commands in one shot.

* Thu Nov 10 2016 ovitters <ovitters> 3.22.2-1.mga6
+ Revision: 1066244
- new version 3.22.2
- new version 3.22.1

* Sun Sep 25 2016 ovitters <ovitters> 3.22.0-1.mga6
+ Revision: 1055926
- add hack for force noach
- new version 3.22.0

* Tue May 10 2016 ovitters <ovitters> 3.20.1-1.mga6
+ Revision: 1012308
- new version 3.20.1

* Tue Mar 22 2016 ovitters <ovitters> 3.20.0-1.mga6
+ Revision: 994156
- new version 3.20.0

* Wed Mar 16 2016 ovitters <ovitters> 3.19.92-1.mga6
+ Revision: 992147
- new version 3.19.92

* Thu Mar 03 2016 ovitters <ovitters> 3.19.91-1.mga6
+ Revision: 985017
- new version 3.19.91

* Fri Feb 19 2016 ovitters <ovitters> 3.19.90-1.mga6
+ Revision: 969804
- new version 3.19.90

* Thu Jan 21 2016 ovitters <ovitters> 3.19.4-1.mga6
+ Revision: 926350
- new version 3.19.4

* Thu Dec 17 2015 ovitters <ovitters> 3.19.3-1.mga6
+ Revision: 911217
- new version 3.19.3

* Wed Nov 25 2015 ovitters <ovitters> 3.19.2-1.mga6
+ Revision: 906054
- new version 3.19.2

* Thu Nov 12 2015 ovitters <ovitters> 3.18.2-1.mga6
+ Revision: 902829
- new version 3.18.2

* Fri Oct 16 2015 tv <tv> 3.18.1-1.mga6
+ Revision: 891985
- new release

* Wed Oct 07 2015 tv <tv> 3.18.0-2.mga6
+ Revision: 886917
- use the upstream session file

* Thu Sep 24 2015 tv <tv> 3.18.0-1.mga6
+ Revision: 882550
- new release

* Wed Sep 16 2015 ovitters <ovitters> 3.17.92-1.mga6
+ Revision: 879934
- new version 3.17.92

* Thu Sep 03 2015 ovitters <ovitters> 3.17.91-1.mga6
+ Revision: 872479
- new version 3.17.91

* Thu Aug 20 2015 ovitters <ovitters> 3.17.90-1.mga6
+ Revision: 866859
- new version 3.17.90

* Thu Jul 23 2015 ovitters <ovitters> 3.17.4-1.mga6
+ Revision: 856337
- new version 3.17.4

* Thu Jul 02 2015 ovitters <ovitters> 3.17.3-1.mga6
+ Revision: 849511
- new version 3.17.3

* Mon Jun 22 2015 ovitters <ovitters> 3.17.2-1.mga6
+ Revision: 839625
- systemMonitor extension was removed upstream
- new version 3.17.2

* Sat Jun 20 2015 ovitters <ovitters> 3.14.4-1.mga6
+ Revision: 836393
- new version 3.14.4

* Mon Dec 22 2014 ovitters <ovitters> 3.14.3-1.mga5
+ Revision: 804815
- new version 3.14.3

* Thu Nov 13 2014 ovitters <ovitters> 3.14.2-1.mga5
+ Revision: 796743
- new version 3.14.2

* Wed Oct 15 2014 umeabot <umeabot> 3.14.1-2.mga5
+ Revision: 738867
- Second Mageia 5 Mass Rebuild
+ ovitters <ovitters>
- new version 3.14.1

* Sun Sep 28 2014 tv <tv> 3.14.0-2.mga5
+ Revision: 731088
- fix group
- recommends launch-new-instance too
- sort
- fix file list
- s/uggests:/Recommends:/
+ ovitters <ovitters>
- new version 3.14.0
- new version 3.13.92
- add gobject-introspection BR for typelib auto BR
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Wed Sep 03 2014 ovitters <ovitters> 3.13.91-1.mga5
+ Revision: 671498
- new version 3.13.91

* Wed Aug 20 2014 ovitters <ovitters> 3.13.90-1.mga5
+ Revision: 665966
- new version 3.13.90

* Thu Jul 24 2014 ovitters <ovitters> 3.13.4-1.mga5
+ Revision: 656376
- new version 3.13.4

* Sat Jun 28 2014 tv <tv> 3.13.3-1.mga5
+ Revision: 640530
- new release

* Tue Mar 25 2014 ovitters <ovitters> 3.12.0-1.mga5
+ Revision: 608583
- new version 3.12.0

* Wed Mar 19 2014 ovitters <ovitters> 3.11.92-1.mga5
+ Revision: 605936
- new version 3.11.92
- ensure gnome-shell is built and available before this package

* Thu Mar 06 2014 ovitters <ovitters> 3.11.91-1.mga5
+ Revision: 600331
- new version 3.11.91

* Thu Feb 20 2014 ovitters <ovitters> 3.11.90-1.mga5
+ Revision: 595013
- new version 3.11.90

* Thu Feb 13 2014 ovitters <ovitters> 3.11.5-2.mga5
+ Revision: 590916
- sync upstream classic start command and custom one

* Thu Feb 06 2014 dams <dams> 3.11.5-1.mga5
+ Revision: 584164
- new version 3.11.5

* Wed Jan 22 2014 colin <colin> 3.10.1-4.mga4
+ Revision: 567452
- Use buildroot RPM macro in favour of env var
- Kill upstream xsession file which overrides our own mga#11582

* Sat Nov 09 2013 ovitters <ovitters> 3.10.1-3.mga4
+ Revision: 550168
- fix url

* Tue Oct 22 2013 umeabot <umeabot> 3.10.1-2.mga4
+ Revision: 545294
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 ovitters <ovitters> 3.10.1-1.mga4
+ Revision: 501043
- new version 3.10.1

* Tue Sep 24 2013 ovitters <ovitters> 3.10.0-1.mga4
+ Revision: 485234
- new version 3.10.0

* Tue Sep 17 2013 ovitters <ovitters> 3.9.92-1.mga4
+ Revision: 480828
- new version 3.9.92

* Tue Sep 03 2013 ovitters <ovitters> 3.9.91-1.mga4
+ Revision: 474648
- new version 3.9.91

* Thu Aug 22 2013 ovitters <ovitters> 3.9.90-2.mga4
+ Revision: 469440
- fix description

* Thu Aug 22 2013 ovitters <ovitters> 3.9.90-1.mga4
+ Revision: 469431
- remove xrandr-indicator, removed upstream due to Wayland support
- new version 3.9.90

* Tue Jul 30 2013 ovitters <ovitters> 3.9.5-1.mga4
+ Revision: 461213
- remove alternative-status-menu subpackage as removed upstream
- new version 3.9.5

* Mon Jul 29 2013 dams <dams> 3.9.4-1.mga4
+ Revision: 460173
- new version 3.9.4

* Sat Jun 22 2013 tv <tv> 3.8.3.1-2.mga4
+ Revision: 445667
- add wmsession file

* Mon Jun 17 2013 ovitters <ovitters> 3.8.3.1-1.mga4
+ Revision: 444176
- new version 3.8.3.1

* Sat Jun 08 2013 dams <dams> 3.8.3-2.mga4
+ Revision: 440737
- Fix obsoletes for deprecated subpackages

* Sat Jun 08 2013 dams <dams> 3.8.3-1.mga4
+ Revision: 440726
- fix specfile for subpackages
+ ovitters <ovitters>
- new version 3.8.3

* Tue May 28 2013 tv <tv> 3.8.2-2.mga4
+ Revision: 429337
- fix obsoleting cauldron's gnome-panem

* Mon May 27 2013 tv <tv> 3.8.2-1.mga4
+ Revision: 428899
- fix build w/o gnome-common
- new release (sync with FC)

* Thu Jan 17 2013 pterjan <pterjan> 3.3.2-1.mga4
+ Revision: 389214
+ rebuild (emptylog)

* Wed Dec 07 2011 wally <wally> 3.3.2-1.mga2
+ Revision: 178538
- new version 3.3.2
- use git archive since upstream hasn't released source tarball

* Mon Oct 03 2011 wally <wally> 3.2.0-1.mga2
+ Revision: 151361
- new version 3.2.0

* Mon Sep 12 2011 wally <wally> 3.1.91-0.1.mga2
+ Revision: 142762
- new version 3.1.91
- get source tarball from upstream git as there's no official release yet
- new version 3.1.4
- enable all extensions
- clean .spec from unneeded stuff

* Wed Jul 13 2011 wally <wally> 3.1.3-2.mga2
+ Revision: 123862
- fix typo in Group (mga#2141)

* Wed Jul 06 2011 wally <wally> 3.1.3-1.mga2
+ Revision: 119516
- new version 3.1.3
- enable xrand-indicator extension
- clean .spec a bit

* Fri Jun 24 2011 mikala <mikala> 3.0.2-1.mga2
+ Revision: 112962
- Add extensions as suggests
- move the require for gnome-shell on -common package
- imported package gnome-shell-extensions


* Sat May 28 2011 Timur Kristóf <venemo@fedoraproject.org> - 3.0.2-1.g63dd27cgit
- Update to a newer git snapshot
- Fix RHBZ bug #708230
- Enabled systemMonitor extension, but commented out since the requirements are not available

* Fri May 13 2011 Mohamed El Morabity <melmorabity@fedoraproject.org> - 3.0.1-3.03660fgit
- Update to a newer git snapshot
- Enable native-window-placement extension

* Fri May 06 2011 Rahul Sundaram <sundaram@fedoraproject.org> - 3.0.1-2b20cbagit
- Fix description 

* Thu May 5 2011 Elad Alfassa <elad@fedoraproject.org> - 3.0.1-1.b20cbagit
- Update to a newer git snapshot
- Enabled the places-menu extension

* Tue Apr 26 2011 Mohamed El Morabity <melmorabity@fedoraproject.org> - 3.0.1-1.f016b9git
- Update to a newer git snapshot (post-3.0.1 release)
- Enable drive-menu extension

* Mon Apr 11 2011 Mohamed El Morabity <melmorabity@fedoraproject.org> - 3.0.0-5.6d56cfgit
- Enable auto-move-windows extension

* Sun Apr 11 2011 Rahul Sundaram <sundaram@fedoraproject.org>  - 3.0.0-4.6d56cfgit
- Add glib2-devel as build requires

* Sun Apr 11 2011 Rahul Sundaram <sundaram@fedoraproject.org>  - 3.0.0-3.6d56cfgit
- Tweak description
- Fix typo in configure

* Sun Apr 11 2011 Rahul Sundaram <sundaram@fedoraproject.org>  - 3.0.0-2.6d56cfgit
- Added the user-theme extension
- Patch from Timur Kristóf <venemo@msn.com>

* Fri Apr 08 2011 Rahul Sundaram <sundaram@fedoraproject.org> - 3.0.0-1.6d56cfgit
- Make sure configure doesn't get called twice

* Fri Apr 08 2011 Rahul Sundaram <sundaram@fedoraproject.org> - 3.0.0-0.6d56cfgit
- Initial build
